# Description

This package contains self used utils and 3rd-party source files that can be call from other python module.

# Files & Functions

- fsext : file system extension, include search, copy files with filter.
- executor : subprocess extension, include windows env setup, use git-bash as executor and more.
- templite : customized [3rd-party](https://pypi.org/project/templite/) template coding module.
- autoupgrade : autoupgrade package use pip, check if remote has a later version of that package.

# TODO

- [ ] more testcase.